-----------------------
-- Version: 0.3
-- Author: Borlak
-----------------------

-----------------------
-- Setting up main table
-----------------------
SupportFunctions = {};

-----------------------
-- General function to provide time for chat entries
-----------------------
function SupportFunctions.GetChatTime()
	return date("%H:%M:%S");
end
-----------------------

-----------------------
-- General print function with timestamp
-----------------------
function SupportFunctions.Print2(ChatLine)
	if(ChatLine == nil) then
		SupportFunctions.Print2("nil");
	elseif(type(ChatLine) == "table") then
		SupportFunctions.Print2("table");
	elseif(type(ChatLine) == "function") then
		SupportFunctions.Print2("function");
	else
		print("[" .. SupportFunctions.GetChatTime() .. "] " .. tostring(ChatLine));
	end
end
-----------------------

-----------------------
-- Dump the content of a table with all sub-tables (for debugging)
-----------------------
function SupportFunctions.TableDump(dumpData, isSubTable, depth)
	if(not dumpData) then SupportFunctions.Print2("nil given!"); return; end
	if(type(dumpData) ~= "table") then SupportFunctions.Print2("Given data is not a table!"); return; end
	
	if(not depth) then
		depth = 0;
	end

	if(not isSubTable) then
		SupportFunctions.Print2(string.rep(">", depth) .. " " .."Table contains " .. getn(dumpData) .. " indexed entries.");
	else
		SupportFunctions.Print2(string.rep(">", depth) .. " " .."Subtable contains " .. getn(dumpData) .. " indexed entries.");
	end
	
	for key, value in pairs(dumpData) do
		if(type(value) == "table") then
			SupportFunctions.TableDump(value, true, depth + 1);
		else
			SupportFunctions.Print2(string.rep(">", depth) .. " " .. tostring(key) .. ": " .. tostring(value));
		end
	end
	
	SupportFunctions.Print2("--------------------");
end
-----------------------

-----------------------
-- Transforms ... to indexed table
-----------------------
function SupportFunctions.TransformDotsToIndexedTable(...)
	local returnTable = {};
	local i = 0;
	local MaxI = 50; -- Amount of entries to check for, will stop at first nil value.
	local entry = nil;

	repeat
		i = i + 1;
		
		entry = select(i, ...);

		if(entry) then
			returnTable[i] = entry;
		end
	until i > MaxI;

	return returnTable;
end
-----------------------

-----------------------
-- Cuts the first n elements of a table and returns the rest
-----------------------
function SupportFunctions.CutElementsFromTableStart(tableData, cutAmount)
	local returnTable = {};
	
	for i = cutAmount + 1, #tableData do
		returnTable[i - cutAmount] = tableData[i];
	end
	
	return returnTable;
end
-----------------------

-----------------------
-- Extract target type from target GUID
-----------------------
function SupportFunctions.GetTypeFromGUID(GUID)
	if(not GUID) then
		return nil;
	else
		local ret = select(1, strsplit("-", GUID));  -- only store first result
		return ret;
	end
end
-----------------------
